@@ -1,11 +1,11 @@
-/* Swinder - Portable library for spreadsheet 
+/* Swinder - Portable library for spreadsheet
    Copyright (C) 2003 Ariya Hidayat <ariya@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
-   
+
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, US
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA
 */
 
 #ifndef SWINDER_VALUE_H
@@ -42,17 +42,17 @@ class ValueData;
 class Value
 {
 
-  public:
+public:
 
     typedef enum {
-      Empty,
-      Boolean,
-      Integer,
-      Float,
-      String,
-      CellRange, // not used yet
-      Array,     // not used yet
-      Error
+        Empty,
+        Boolean,
+        Integer,
+        Float,
+        String,
+        CellRange, // not used yet
+        Array,     // not used yet
+        Error
     } Type;
 
     /**
@@ -60,53 +60,53 @@ class Value
      */
     Value();
 
-    /** 
+    /**
      * Creates a value of certain type.
      */
-    Value( Type _type );
+    explicit Value(Type _type);
 
-    /** 
+    /**
      * Destroys the value.
      */
     virtual ~Value();
 
-    /** 
+    /**
      * Creates a copy from another value.
      */
-    Value( const Value& _value );
+    Value(const Value& _value);
 
-    /** 
+    /**
      * Assigns from another value.
      *
      * Because the data is implicitly shared, such assignment is very fast and
      * doesn't consume additional memory.
      */
-    Value& operator= ( const Value& _value );
+    Value& operator= (const Value& _value);
 
-    /** 
+    /**
      * Assigns from another value. Same as above.
      */
-    Value& assign( const Value& _value );
+    Value& assign(const Value& _value);
 
     /**
      * Creates a boolean value.
      */
-    Value( bool b );
+    explicit Value(bool b);
 
     /**
      * Creates an integer value.
      */
-    Value( int i );
+    explicit Value(int i);
 
     /**
      * Create a floating-point value.
      */
-    Value( double f );
+    explicit Value(double f);
 
-    /** 
+    /**
      * Create a string value.
      */
-    Value( const UString& s );
+    explicit Value(const UString& s);
 
     /**
      * Returns the type of the value.
@@ -116,65 +116,79 @@ class Value
     /**
      * Returns true if empty.
      */
-    bool isEmpty() const { return type() == Empty; }
+    bool isEmpty() const {
+        return type() == Empty;
+    }
 
     /**
      * Returns true if the type of this value is Boolean.
      */
-    bool isBoolean() const { return type() == Boolean; }
+    bool isBoolean() const {
+        return type() == Boolean;
+    }
 
     /**
      * Returns true if the type of this value is integer.
      */
-    bool isInteger() const { return type() == Integer; }
+    bool isInteger() const {
+        return type() == Integer;
+    }
 
     /**
      * Returns true if the type of this value is floating-point.
      */
-    bool isFloat() const { return type() == Float; }
+    bool isFloat() const {
+        return type() == Float;
+    }
 
     /**
-     * Returns true if the type of this value is either 
+     * Returns true if the type of this value is either
      * integer or floating-point.
      */
-    bool isNumber() const { return (type() == Integer) || (type() == Float); }
+    bool isNumber() const {
+        return (type() == Integer) || (type() == Float);
+    }
 
     /**
      * Returns true if the type of this value is string.
      */
-    bool isString() const { return type() == String; }
+    bool isString() const {
+        return type() == String;
+    }
 
     /**
      * Returns true if this value holds error information.
      */
-    bool isError() const { return type() == Error; }
+    bool isError() const {
+        return type() == Error;
+    }
 
-    void setValue( const Value& v );
+    void setValue(const Value& v);
 
     /**
      * Sets this value to boolean value.
      */
-    void setValue( bool b );
+    void setValue(bool b);
 
     /**
      * Sets this value to integer value.
      */
-    void setValue( int i );
+    void setValue(int i);
 
     /**
      * Sets this value to floating-point value.
      */
-    void setValue( double f );
+    void setValue(double f);
 
     /**
      * Sets this value to string value.
      */
-    void setValue( const UString& s );
+    void setValue(const UString& s);
 
     /**
      * Sets this value to hold error message.
      */
-    void setError( const UString& msg );
+    void setError(const UString& msg);
 
     /**
      * Returns the boolean value of this value.
@@ -224,58 +238,58 @@ class Value
     static const Value& empty();
 
     /**
-     * Returns constant reference to #DIV/0! error.
+     * Returns constant reference to \#DIV/0! error.
      *
      * This is used to indicate that a formula divides by 0 (zero).
      */
     static const Value& errorDIV0();
 
     /**
-     * Returns constant reference to #N/A error.
+     * Returns constant reference to \#N/A error.
      *
      * This is to indicate that  a value is not available to a function.
      */
     static const Value& errorNA();
 
     /**
-     * Returns constant reference to #NAME? error.
+     * Returns constant reference to \#NAME? error.
      *
-     * This is to indicate that certain text inside formula is not 
-     * recognized, possibly a misspelled name or name that 
+     * This is to indicate that certain text inside formula is not
+     * recognized, possibly a misspelled name or name that
      * does not exist.
      */
     static const Value& errorNAME();
 
     /**
-     * Returns constant reference to #NUM! error.
+     * Returns constant reference to \#NUM! error.
      *
      * This is to indicate a problem with a number in a formula.
      */
     static const Value& errorNUM();
 
     /**
-     * Returns constant reference to #NULL! error.
+     * Returns constant reference to \#NULL! error.
      *
      * This is to indicate that two area do not intersect.
      */
     static const Value& errorNULL();
 
     /**
-     * Returns constant reference to #REF! error.
+     * Returns constant reference to \#REF! error.
      *
      * This is used to indicate an invalid cell reference.
      */
     static const Value& errorREF();
 
     /**
-     * Returns constant reference to #VALUE! error.
+     * Returns constant reference to \#VALUE! error.
      *
      * This is to indicate that wrong type of argument or operand
      * is used, usually within a function call, e.g SIN("some text").
      */
     static const Value& errorVALUE();
 
-  protected:
+protected:
 
     ValueData* d; // can't never be 0
 };
@@ -283,7 +297,7 @@ class Value
 /**
  * Dumps value to output stream, useful for debugging.
  */
-std::ostream& operator<<( std::ostream& s, Value value );
+std::ostream& operator<<(std::ostream& s, Value value);
 
 } // namespace Swinder
 
