@@ -13,32 +13,30 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef DOCBOOKEXPORT_H
 #define DOCBOOKEXPORT_H
 
-#include <qstring.h>
-#include <qcstring.h>
-#include <qfile.h>
-#include <qobject.h>
+#include <QString>
+#include <QFile>
+#include <QObject>
 
-#include <koFilter.h>
-#include <koStore.h>
+#include <KoFilter.h>
+#include <KoStore.h>
 
 
-class DocBookExport : public KoFilter {
+class DocBookExport : public KoFilter
+{
 
     Q_OBJECT
 
 public:
-    DocBookExport (KoFilter *parent, const char *name );
+    DocBookExport(QObject *parent, const QStringList &);
     virtual ~DocBookExport() {}
-    /** filtering :) */
-    virtual bool filter(const QString &fileIn, const QString &fileOut,
-                        const QString &from, const QString &to,
-                        const QString &config=QString::null);
+
+    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
 };
 #endif // DOCBOOKEXPORT_H
